# Contributing guidelines

Contributions are highly welcomed and appreciated. Please follow these guidelines when
contributing to the project:

1. Fork the repository.
2. Install [pre-commit](https://pre-commit.com) and run ``pre-commit install`` to ensure style-guides and code checks are followed.
3. Make your changes (not forgetting documentation and tests).
4. Ensure tests are passing using ``tox``.
